@@ -2,8 +2,7 @@
    basic cddb functions for XfreeCD
 
    Copyright 1998 by Brian C. Lane
-   nexus@tatoosh.com
-   http://www.tatoosh.com/nexus
+   http://www.brianlane.com/
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
