@@ -2,8 +2,7 @@
    cddbd include file for XfreeCD
 
    Copyright 1998 by Brian C. Lane
-   nexus@tatoosh.com
-   http://www.tatoosh.com/nexus
+   http://www.brianlane.com/
 
    ------------------------------------------------------------------------ */
 #define DB_DIAG        0x00
