@@ -4,8 +4,7 @@
    part of XfreeCD
 
    Copyright 1998 by Brian C. Lane
-   nexus@tatoosh.com
-   http://www.tatoosh.com/nexus
+   http://www.brianlane.com/
 
    ==========================[ HISTORY ]==================================
    05/09/98    Moved these functions into this seperate file
