@@ -2,8 +2,7 @@
    child_sync include file for XfreeCD
 
    Copyright 1998 by Brian C. Lane
-   nexus@tatoosh.com
-   http://www.tatoosh.com/nexus
+   http://www.brianlane.com/
 
    ------------------------------------------------------------------------ */
 int parent_sync( int fd );
