@@ -2,12 +2,11 @@
    xfreecd include file for XfreeCD
 
    Copyright 1998 by Brian C. Lane
-   nexus@tatoosh.com
-   http://www.tatoosh.com/nexus
+   http://www.brianlane.com/
 
    ------------------------------------------------------------------------ */
-#define DEFAULT_CDDB_PATH "~/.cddb"
-#define DEFAULT_SERVER    "cddb.cddb.com"
+#define DEFAULT_CDDB_PATH "~/.config/CDDB"
+#define DEFAULT_SERVER    "freedb.freedb.org"
 #define DEFAULT_DEVICE    "/dev/cdrom"
 #define DEFAULT_TO_CDDBD  "xmcd-cddb@amb.org"
 #define MAIL_BINARY       "mail"
@@ -29,6 +28,7 @@ struct CONFIG {
   short  exit_eject;            /* Eject on Exit when not playing */
   short  startup;               /* What should we do at startup? See STARTUP_* */
   short  cddb;                  /* Is cddb support enabled? */
+  short  wm_no_decor;           /* Hide main window decorations? */
   short  changer;               /* Is IDE CD changer support enabled? */
   short  saved;                 /* Saved state. 1 = saved, 0 = needs to be saved */
 };
